@@ -9,6 +9,12 @@ class Checkpoint():
         self.every = _every
         self.filepath = _filepath
 
+        # build path if not already exists
+        head, tail = os.path.split(self.filepath)
+
+        if not os.path.exists(head):
+            os.makedirs(head)
+
     def run(self):
         """
         Check if necessary to do backup based on `_every` variable
